@@ -4,7 +4,7 @@
 modname = 'addressbook'
 distname = "cubicweb-%s" % modname
 
-numversion = (1, 6, 3)
+numversion = (1, 7, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -19,7 +19,9 @@ classifiers = [
     'Programming Language :: JavaScript',
     ]
 
-__depends__ = {'cubicweb': '>= 3.13.8'}
+__depends__ = {'cubicweb': '>= 3.17.0',
+               'cubicweb-geocoding': None,
+               }
 
 
 # packaging ###
