@@ -8,7 +8,7 @@
 
 __docformat__ = 'restructuredtext en'
 
-from cubes.addressbook import geocoding
+from cubes.geocoding import geocoding
 
 from cubicweb.selectors import is_instance
 from cubicweb.server.hook import Hook
